# -------------- Elmer CurrentSolver check with AWG20 wire and air  -----#
#                                                                        # 
# AWG d(in)     A(in2)        d(mm)     A(mm2)      R(Ohm/km)            #
# 20  0,031960  0,0008022377  0,811784  0,51757167  34,39                #
#                                                                        #
# expect 0.5m of AWG20 to have (34.39Ohm/km)/20000= 1.72mOhm             #
#                                                                        #
# -----------------------------------------------------------------------#


import geompy
import salome
gg = salome.ImportComponentGUI("GEOM")

#Constants
AWG20 = 0.811784/1000  #diameter, converted to meters

# make the air volume, with 10cm sides
aircube = geompy.MakeBox(-0.05,-0.05,-0.05,0.05,0.05,0.05)

# make the AWG20 wire, l=5cm, in x-direction
wire_origin = geompy.MakeVertex(-0.025,0,0)
wire_direction = geompy.MakeVectorDXDYDZ(1,0,0) 
wireAWG20 = geompy.MakeCylinder(wire_origin,wire_direction,(AWG20/2),0.05)

# make partition
p1 = geompy.MakePartition([wireAWG20,aircube],[],[],[],geompy.ShapeType["SOLID"], 0, [], 0)

 # GetObjectIDs
p1_solids = geompy.ExtractShapes(p1, geompy.ShapeType["SOLID"], True) #gets all solids in partition
id_p1_solids = [] #initialize the array
for aSolid in range(0,len(p1_solids)):
	id_p1_solids.append(geompy.GetSubShapeID(p1, p1_solids[aSolid])) #get the ID of the solid and add it to the array
	print " ", id_p1_solids[aSolid] #print the ID

# make groups
g1 = geompy.CreateGroup(p1, geompy.ShapeType["SOLID"])
g2 = geompy.CreateGroup(p1, geompy.ShapeType["SOLID"])

geompy.AddObject(g1, id_p1_solids[0])
geompy.AddObject(g2, id_p1_solids[1])

# add objects in the study
id_p1 = geompy.addToStudy(p1,"Part1")
id_g1 = geompy.addToStudyInFather(p1, g1, 'Wire AWG20' )
id_g2 = geompy.addToStudyInFather(p1, g2, 'Air Cube' )

# display
gg.createAndDisplayGO(id_p1)
gg.setDisplayMode(id_p1,1)
gg.setColor(id_p1, 150, 150, 180)
gg.setTransparency(id_p1, 0.8)


# -------------- meshing -----------------------------------------------

import smesh, SMESH, SALOMEDS

# create a mesh
tetraN = smesh.Mesh(p1, "Mesh_1")

# create a Netgen_2D3D algorithm for solids
algo3D = tetraN.Tetrahedron(smesh.FULL_NETGEN) 

# define hypotheses
n23_params = algo3D.Parameters()

# compute the mesh
tetraN.Compute()
smesh.SetName(tetraN.GetMesh(), 'Mesh_1')

# create mesh groups
id_Grp_1 = tetraN.GroupOnGeom(g1,'meshWire',SMESH.VOLUME)

id_Grp_2 = tetraN.GroupOnGeom(g2,'meshAir',SMESH.VOLUME)

print "finished"
